@@ -89,6 +89,7 @@ class TrajectoryPlayer(DOMWidget):
         self.observe(self._on_widget_built, names=['widget_repr_parameters',
             'widget_repr',
             'widget_preference'])
+        self._movie_maker = None
 
     def _on_widget_built(self, change):
         widget = change['new']
@@ -209,7 +210,6 @@ class TrajectoryPlayer(DOMWidget):
                        (self._make_widget_preference, 'Preference'),
                        (self._make_theme_box, 'Theme'),
                        (self._make_extra_box, 'Extra'),
-                       (self._make_hide_tab_with_place_proxy, 'Hide'),
                        (self._show_website, 'Help')]
 
         tab = _make_delay_tab(box_factory, selected_index=-1)
@@ -224,9 +224,6 @@ class TrajectoryPlayer(DOMWidget):
     def _make_widget_tab(self):
         return self._display()
 
-    def _make_hide_tab_with_place_proxy(self):
-        return Box([self._view._place_proxy])
-
     def _make_button_center(self):
         button = Button(description=' Center', icon='fa-bullseye')
         @button.on_click
