@@ -1,14 +1,13 @@
 from __future__ import print_function, absolute_import
-
+import threading
 import time
 import base64
 import uuid
 import json
-import threading
 import numpy as np 
 from IPython.display import display
-from ipywidgets import DOMWidget, widget_image, PlaceProxy
-from traitlets import (Unicode, Bool, Dict, List, Int, observe,
+from ipywidgets import DOMWidget, widget_image
+from traitlets import (Unicode, Bool, Dict, List, Int, Integer, observe,
                        CaselessStrEnum)
 
 from .utils import py_utils, js_utils, widget_utils
@@ -24,6 +23,7 @@ from .representation import RepresentationControl
 from .adaptor import Structure, Trajectory
 from .config import BACKENDS
 from .parameters import REPRESENTATION_NAME_PAIRS
+from .remote_thread import RemoteCallThread
 
 __all__ = ['NGLWidget', 'ComponentViewer']
 
@@ -74,42 +74,13 @@ def _add_repr_method_shortcut(self, other):
             fn = '_'.join((root_fn, rep[0]))
             setattr(self, fn, MethodType(func, other))
 
-class RemoteCallThread(threading.Thread):
-    def __init__(self, view, timeout=0.1):
-        self.q = []
-        self.view = view
-        self.timeout = timeout
-        super(RemoteCallThread, self).__init__()
-        self.daemon = True
-
-    def run(self):
-        # this `run` method will be called if `start` the thread
-        # How does this work?
-        # First, try to pop all callbacks and execute them, if loadFile
-        # then wait until getting 'ok' signal from NGL. Calling those callbacks
-        # will block execution from other threads. This is why we let this thread
-        # run forever in background. This thread is usually sleeping all the time
-        # and let other threads do the work. It "wake up" only if its 'q' is added more
-        # callbacks
-
-        # This class is needed if use call 
-        # add_trajectory, clear, add_representation, ... in the same notebook cell
-        while True:
-            try:
-                callback = self.q.pop(0)
-                callback(self.view)
-                if callback._method_name in ['loadFile']:
-                    self.view._wait_until_finished()
-            except IndexError:
-                time.sleep(self.timeout)
-
 class NGLWidget(DOMWidget):
     _view_name = Unicode("NGLView").tag(sync=True)
     _view_module = Unicode("nglview-js-widgets").tag(sync=True)
     _image_data = Unicode().tag(sync=True)
-    selector = Unicode().tag(sync=True)
-    frame = Int().tag(sync=True)
-    count = Int(1).tag(sync=True)
+    # use Integer here, because mdtraj uses a long datatype here on Python-2.7
+    frame = Integer().tag(sync=True)
+    count = Integer(1).tag(sync=True)
     background = Unicode('white').tag(sync=True)
     loaded = Bool(False).tag(sync=False)
     picked = Dict().tag(sync=True)
@@ -118,8 +89,6 @@ class NGLWidget(DOMWidget):
     _first_time_loaded = Bool(True).tag(sync=False)
     # hack to always display movie
     _n_dragged_files = Int().tag(sync=True)
-    _init_representations = List().tag(sync=True)
-    _init_structures_sync = List().tag(sync=True)
     # TODO: remove _parameters?
     _parameters = Dict().tag(sync=False)
     _full_stage_parameters = Dict().tag(sync=True)
@@ -156,12 +125,11 @@ class NGLWidget(DOMWidget):
         # # register to get data from JS side
         self._handle_msg_thread.daemon = True
         self._handle_msg_thread.start()
-        self._remote_call_thread = RemoteCallThread(self)
+        self._remote_call_thread = RemoteCallThread(self,
+                registered_funcs=['loadFile', 'replaceStructure'])
         self._remote_call_thread.start()
         self._trajlist = []
         self._ngl_component_ids = []
-        self._init_structures = []
-
         if parameters:
             self.parameters = parameters
         if isinstance(structure, Trajectory):
@@ -176,8 +144,6 @@ class NGLWidget(DOMWidget):
             if structure is not None:
                 self.add_structure(structure, **kwargs)
 
-        # call before setting representations
-        self._set_initial_structure(self._init_structures)
         if representations:
             self._init_representations = representations
         else:
@@ -198,10 +164,8 @@ class NGLWidget(DOMWidget):
             self._representations = self._init_representations[:]
 
         self._set_unsync_camera()
-        self.selector = str(uuid.uuid4()).replace('-', '')
-        self._remote_call('setSelector', target='Widget', args=[self.selector,])
-        self.selector = '.' + self.selector # for PlaceProxy
-        self._place_proxy = PlaceProxy(child=None, selector=self.selector)
+        selector = 'nglviewHolder' + str(id(self))
+        self._remote_call('setSelector', target='Widget', args=[selector,])
         self.player = TrajectoryPlayer(self)
         self._already_constructed = True
 
@@ -304,8 +268,9 @@ class NGLWidget(DOMWidget):
                     reprlist_choices.value = reprlist_choices.options[repr_slider.value]
                 except IndexError:
                     if repr_slider.value == 0:
-                        reprlist_choices.options = tuple(['',])
-                        reprlist_choices.value = ''
+                        # works fine with ipywidgets 5.2.2
+                        reprlist_choices.options = tuple([' ',])
+                        reprlist_choices.value = ' '
                     else:
                         reprlist_choices.value = reprlist_choices.options[repr_slider.value-1]
 
@@ -391,8 +356,6 @@ class NGLWidget(DOMWidget):
             self._remote_call('cleanOutput',
                               target='Widget')
 
-        self._place_proxy._ipython_display_()
-
     def display(self, gui=False, use_box=False):
         if gui:
             if use_box:
@@ -403,31 +366,25 @@ class NGLWidget(DOMWidget):
             else:
                 display(self)
                 display(self.player._display())
-                display(self._place_proxy)
                 return None
         else:
             return self
 
-    def _set_place_proxy(self, widget):
-        """
+    def _set_size(self, w, h):
+        '''
 
         Parameters
         ----------
-        widget : instance of ipywidgets.DOMWidget (or derived class)
+        w, h : float or str
 
         Examples
         --------
-        >>> from ipywidgets import IntSlider
-        >>> slider = IntSlider()
-        >>> import nglview
-        >>> view = nglview.demo()
-        >>> view
-        >>> view._set_place_proxy(slider)
-        >>> view._place_proxy
-        >>> # TODO: _place_proxy only has effect (adding widget to NGLWidget)
-        >>> # if it was displayed (should fix)
-        """
-        self._place_proxy.child = widget
+        >>> view._set_size(100, 100)
+        >>> view._set_size('100px', '100px')
+        >>> view._set_size('50%', '50%')
+        '''
+        self._remote_call('setSize', target='Widget',
+                args=[w, h])
 
     def _set_draggable(self, yes=True):
         if yes:
@@ -573,29 +530,12 @@ class NGLWidget(DOMWidget):
         r = str(repr_index)
 
         try:
-            name = self._repr_dict[c][r]['name']
+            name = self._repr_dict[c][r]['type']
         except KeyError:
             name = ''
 
         return RepresentationControl(self, component, repr_index, name=name)
 
-    def _set_initial_structure(self, structures):
-        """initialize structures for Widget
-
-        Parameters
-        ----------
-        structures : list
-            list of Structure or Trajectory
-        """
-        _init_structures_sync = structures if isinstance(structures, (list, tuple)) else [structures,]
-        if _init_structures_sync:
-            self._init_structures_sync = [
-                        {"data": _structure.get_structure_string(),
-                         "ext": _structure.ext,
-                         "params": _structure.params,
-                         "id": _structure.id}
-                    for _structure in _init_structures_sync]
-
     def _set_coordinates(self, index):
         '''update coordinates for all trajectories at index-th frame
         '''
@@ -867,6 +807,34 @@ class NGLWidget(DOMWidget):
                           args=[filename,],
                           kwargs=params)
 
+    def _get_movie_maker(self, in_memory=True, **kwargs):
+        ''' create MovieMaker object
+
+        Examples
+        --------
+        >>> movie = view._get_movie_maker(output='my.gif')
+        >>> movie.make()
+
+
+        Notes
+        -----
+        We only test with imageio 1.6 and moviepy 0.2.2.11
+        Good luck.
+        '''
+        try:
+            import moviepy
+        except ImportError:
+            print("You must install moviepy and ffmeg")
+            print("pip install moviepy==0.2.2.11")
+            print("pip install imageio==1.6")
+        from nglview.contrib.movie import MovieMaker
+
+        if 'in_memory' not in kwargs:
+            kwargs['in_memory'] = in_memory 
+
+        movie_maker = MovieMaker(self, **kwargs)
+        return movie_maker
+
     def _ngl_handle_msg(self, widget, msg, buffers):
         """store message sent from Javascript.
 
@@ -902,7 +870,7 @@ class NGLWidget(DOMWidget):
                 # so two viewers can have the same representations
                 self.loaded = False
             self.loaded = msg.get('data')
-        elif msg_type == 'all_reprs_info':
+        elif msg_type == 'repr_dict':
             self._repr_dict = self._ngl_msg.get('data')
         elif msg_type == 'stage_parameters':
             self._full_stage_parameters = msg.get('data')
@@ -936,15 +904,10 @@ class NGLWidget(DOMWidget):
         '''
         if not isinstance(structure, Structure):
             raise ValueError('{} is not an instance of Structure'.format(structure))
-        if self.loaded or self._already_constructed:
-            self._load_data(structure, **kwargs)
-        else:
-            # update via structure_list
-            self._init_structures.append(structure)
-            name = py_utils.get_name(structure, kwargs)
-            self._ngl_component_names.append(name)
+        self._load_data(structure, **kwargs)
         self._ngl_component_ids.append(structure.id)
-        self.center_view(component=len(self._ngl_component_ids)-1)
+        if self.n_components > 1:
+            self.center_view(component=len(self._ngl_component_ids)-1)
         self._update_component_auto_completion()
 
     def add_trajectory(self, trajectory, **kwargs):
@@ -979,13 +942,7 @@ class NGLWidget(DOMWidget):
         else:
             trajectory = trajectory
 
-        if self.loaded or self._already_constructed:
-            self._load_data(trajectory, **kwargs)
-        else:
-            # update via _init_structures_sync
-            self._init_structures.append(trajectory)
-            name = py_utils.get_name(trajectory, kwargs)
-            self._ngl_component_names.append(name)
+        self._load_data(trajectory, **kwargs)
         setattr(trajectory, 'shown', True)
         self._trajlist.append(trajectory)
         self._update_count()
